From 6eaaa70ea8ee9cd1044dbd101d6573d2e134d0f2 Mon Sep 17 00:00:00 2001
From: redray <redray@ispconfig3>
Date: Mon, 01 Dec 2008 05:19:20 -0500
Subject: [PATCH] added auto-revision from svn to version
---
interface/web/dns/dns_alias_edit.php | 29 ++++++++++++++++++++++++-----
1 files changed, 24 insertions(+), 5 deletions(-)
diff --git a/interface/web/dns/dns_alias_edit.php b/interface/web/dns/dns_alias_edit.php
index f08280d..134fab5 100644
--- a/interface/web/dns/dns_alias_edit.php
+++ b/interface/web/dns/dns_alias_edit.php
@@ -41,11 +41,8 @@
require_once('../../lib/config.inc.php');
require_once('../../lib/app.inc.php');
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'dns')) {
- header("Location: ../index.php");
- exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('dns');
// Loading classes
$app->uses('tpl,tform,tform_actions');
@@ -105,6 +102,28 @@
parent::onSubmit();
}
+
+ function onAfterInsert() {
+ global $app, $conf;
+
+ // Update the serial number of the SOA record
+ $soa_id = intval($_POST["zone"]);
+ $serial = time();
+ $app->db->query("UPDATE dns_soa SET serial = $serial WHERE id = $soa_id");
+
+ // Set the sys_groupid of the rr record to be the same then the sys_groupid of the soa record
+ $soa = $app->db->queryOneRecord("SELECT sys_groupid FROM dns_soa WHERE id = '".intval($this->dataRecord["zone"])."' AND ".$app->tform->getAuthSQL('r'));
+ $app->db->query("UPDATE dns_rr SET sys_groupid = ".$soa['sys_groupid']." WHERE id = ".$this->id);
+ }
+
+ function onAfterUpdate() {
+ global $app, $conf;
+
+ // Update the serial number of the SOA record
+ $soa_id = intval($_POST["zone"]);
+ $serial = time();
+ $app->db->query("UPDATE dns_soa SET serial = $serial WHERE id = $soa_id");
+ }
}
$page = new page_action;
--
Gitblit v1.9.1